window.Gleam.initSearch([{"doc":"gleamy_bench","title":"gleamy_bench","content":"# gleamy_bench\n\n[![Package Version](https://img.shields.io/hexpm/v/gleamy_bench)](https://hex.pm/packages/gleamy_bench)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleamy_bench/)\n\nA library for benchmarking gleam code.\n\n# How To\n\n```rust\n\nbench.run(\n    [\n      bench.Input(&quot;pre-sorted list&quot;, list.range(1, 100_000)),\n      bench.Input(&quot;reversed list&quot;, list.range(1, 100_000) |&gt; list.reverse),\n    ],\n    [\n        bench.Function(&quot;list.sort()&quot;, sort_int)\n    ],\n    [\n        bench.Duration(1000),\n        bench.Warmup(100)\n    ],\n  )\n|&gt; bench.table([bench.IPS, bench.Min, bench.P(99)])\n|&gt; io.println()\n\n```\n\nA benchmark is defined by giving a list of inputs and a list of functions to run on those inputs. Each input + function combination will be timed.\n\nThe given inputs should all be the same type, and the functions should all accept that type as the only argument.\n\nThe `run` function actually runs the benchmark and collects the results. It also accepts a list of options to change default behaviour, for example `Duration(1000)` is used to change how long each function is run repeatedly when collecting results (in milliseconds). This list is optional and can be empty if you have no need to change the defaults.\n\nThe `table` function makes a table out of the results. You can choose the list of statistics you would like to include in the table.\n\nThe output for this example looks like the following.\n\n```\nInput                   Function                           IPS             Min             P99\npre-sorted list         list.sort()                    37.8532         22.4190         31.3593\nreversed list           list.sort()                    34.0101         27.0734         31.0618\n```\n\n## Contributing\n\nSuggestions and pull requests are welcome!\n\n## Quick start\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add gleamy_bench\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/gleamy_bench&gt;.\n","url":"index.html"},{"doc":"gleamy_bench","title":"Function","content":"pub type Function(a, b) {\n  Function(label: String, function: fn(a) -&gt; b)\n}\n\nFunction(label: String, function: fn(a) -&gt; b)\n\n\nSynonyms:\ngleamy_bench.Function\ngleamy_bench Function","url":"gleamy_bench.html#Function"},{"doc":"gleamy_bench","title":"Input","content":"pub type Input(a) {\n  Input(label: String, value: a)\n}\n\nInput(label: String, value: a)\n\n\nSynonyms:\ngleamy_bench.Input\ngleamy_bench Input","url":"gleamy_bench.html#Input"},{"doc":"gleamy_bench","title":"Option","content":"pub type Option {\n  Warmup(ms: Int)\n  Duration(ms: Int)\n  Quiet\n}\n\nWarmup(ms: Int)\n\n\nDuration(ms: Int)\n\n\nQuiet\n\n\nSynonyms:\ngleamy_bench.Option\ngleamy_bench Option","url":"gleamy_bench.html#Option"},{"doc":"gleamy_bench","title":"Set","content":"pub type Set {\n  Set(input: String, function: String, reps: List(Float))\n}\n\nSet(input: String, function: String, reps: List(Float))\n\n\nSynonyms:\ngleamy_bench.Set\ngleamy_bench Set","url":"gleamy_bench.html#Set"},{"doc":"gleamy_bench","title":"Stat","content":"pub type Stat {\n  P(Int)\n  IPS\n  Min\n  Max\n  Mean\n  SD\n  SDPercent\n  Stat(name: String, calculate: fn(Set) -&gt; Float)\n}\n\nP(Int)\n\n\nIPS\n\n\nMin\n\n\nMax\n\n\nMean\n\n\nSD\n\n\nSDPercent\n\n\nStat(name: String, calculate: fn(Set) -&gt; Float)\n\n\nSynonyms:\ngleamy_bench.Stat\ngleamy_bench Stat","url":"gleamy_bench.html#Stat"},{"doc":"gleamy_bench","title":"do_repeat","content":"pub fn do_repeat(n: Int, input: a, fun: fn(a) -&gt; b) -&gt; Nil\n\nSynonyms:\ngleamy_bench.do_repeat\ngleamy_bench do_repeat","url":"gleamy_bench.html#do_repeat"},{"doc":"gleamy_bench","title":"repeat","content":"pub fn repeat(n: Int, fun: fn(a) -&gt; b) -&gt; fn(a) -&gt; Nil\n\nSynonyms:\ngleamy_bench.repeat\ngleamy_bench repeat","url":"gleamy_bench.html#repeat"},{"doc":"gleamy_bench","title":"run","content":"pub fn run(\n  inputs: List(Input(a)),\n  functions: List(Function(a, b)),\n  options: List(Option),\n) -&gt; List(Set)\n\nSynonyms:\ngleamy_bench.run\ngleamy_bench run","url":"gleamy_bench.html#run"},{"doc":"gleamy_bench","title":"table","content":"pub fn table(sets: List(Set), stats: List(Stat)) -&gt; String\n\nSynonyms:\ngleamy_bench.table\ngleamy_bench table","url":"gleamy_bench.html#table"},{"doc":"gleamy_bench","title":"gleamy_bench","content":"","url":"gleamy_bench.html"},{"doc":"gleamy_bench_example","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\ngleamy_bench_example.main\ngleamy_bench_example main","url":"gleamy_bench_example.html#main"},{"doc":"gleamy_bench_example","title":"gleamy_bench_example","content":"","url":"gleamy_bench_example.html"},{"doc":"test","title":"Ctrl","content":"pub type Ctrl(a) {\n  Pure(a)\n  Yield(\n    marker: String,\n    op: fn(fn(a) -&gt; Ctrl(a)) -&gt; Ctrl(a),\n    cont: fn(a) -&gt; Ctrl(a),\n  )\n}\n\nPure(a)\n\n\nYield(\n  marker: String,\n  op: fn(fn(a) -&gt; Ctrl(a)) -&gt; Ctrl(a),\n  cont: fn(a) -&gt; Ctrl(a),\n)\n\n\nSynonyms:\ntest.Ctrl\ntest Ctrl","url":"test.html#Ctrl"},{"doc":"test","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\ntest.main\ntest main","url":"test.html#main"},{"doc":"test","title":"mprompt","content":"pub fn mprompt(marker: String, ctl: Ctrl(a)) -&gt; Ctrl(a)\n\nSynonyms:\ntest.mprompt\ntest mprompt","url":"test.html#mprompt"},{"doc":"test","title":"prompt","content":"pub fn prompt(marker: String, action: fn() -&gt; Ctrl(a)) -&gt; Ctrl(a)\n\nSynonyms:\ntest.prompt\ntest prompt","url":"test.html#prompt"},{"doc":"test","title":"yield","content":"pub fn yield(\n  marker: String,\n  op: fn(fn(a) -&gt; Ctrl(a)) -&gt; Ctrl(a),\n) -&gt; Ctrl(a)\n\nSynonyms:\ntest.yield\ntest yield","url":"test.html#yield"},{"doc":"test","title":"test","content":"","url":"test.html"}]);